Xandikos uses the :PEP:`8` style guide.
You can verify whether you've introduced any style violations by running
"make style".

There are some very minimal developer documentation/vague design docs in notes/.

Please implement new RFCs as much as possible in their own file.
